@@ -75,11 +75,16 @@ from yellowdog_cli.utils.printing import (
     sorted_objects,
 )
 from yellowdog_cli.utils.settings import (
+    PROP_GROUPS,
+    PROP_RESOURCE,
     RN_ALLOWANCE,
+    RN_APPLICATION,
+    RN_GROUP,
     RN_IMAGE_FAMILY,
     RN_KEYRING,
     RN_NUMERIC_ATTRIBUTE_DEFINITION,
     RN_REQUIREMENT_TEMPLATE,
+    RN_ROLE,
     RN_SOURCE_TEMPLATE,
     RN_STRING_ATTRIBUTE_DEFINITION,
 )
@@ -104,7 +109,7 @@ def main():
         ARGS_PARSER.details = True
 
     if ARGS_PARSER.details and ARGS_PARSER.strip_ids:
-        print_log("Omitting YellowDog IDs from detailed JSON objects")
+        print_log("Omitting YellowDog IDs (etc.) from detailed JSON objects")
 
     if ARGS_PARSER.output_file and ARGS_PARSER.details:
         if exists(ARGS_PARSER.output_file):
@@ -584,7 +589,7 @@ def list_compute_requirement_templates():
                 CLIENT,
                 CLIENT.compute_client.get_compute_requirement_template(cr_template.id),
             ),
-            RN_REQUIREMENT_TEMPLATE,
+            {PROP_RESOURCE: RN_REQUIREMENT_TEMPLATE},
         )
         for cr_template in cr_templates
     ]
@@ -633,7 +638,7 @@ def list_compute_source_templates():
                 CLIENT,
                 CLIENT.compute_client.get_compute_source_template(cs_template.id),
             ),
-            RN_SOURCE_TEMPLATE,
+            {PROP_RESOURCE: RN_SOURCE_TEMPLATE},
         )
         for cs_template in cs_templates
     ]
@@ -662,7 +667,7 @@ def list_keyrings():
 
     # Show details
     print_yd_object_list(
-        [(keyring, RN_KEYRING) for keyring in select(CLIENT, keyrings)]
+        [(keyring, {PROP_RESOURCE: RN_KEYRING}) for keyring in select(CLIENT, keyrings)]
     )
 
 
@@ -712,7 +717,7 @@ def list_image_families():
     image_families = [
         (
             CLIENT.images_client.get_image_family_by_id(image_family_summary.id),
-            RN_IMAGE_FAMILY,
+            {PROP_RESOURCE: RN_IMAGE_FAMILY},
         )
         for image_family_summary in image_family_summaries
     ]
@@ -809,7 +814,10 @@ def list_allowances():
 
     # Show details
     print_yd_object_list(
-        [(allowance, RN_ALLOWANCE) for allowance in select(CLIENT, allowances)]
+        [
+            (allowance, {PROP_RESOURCE: RN_ALLOWANCE})
+            for allowance in select(CLIENT, allowances)
+        ]
     )
 
 
@@ -841,11 +849,13 @@ def list_attribute_definitions():
     attribute_definition_list = [
         (
             attribute,
-            (
-                RN_NUMERIC_ATTRIBUTE_DEFINITION
-                if "Numeric" in attribute["type"]
-                else RN_STRING_ATTRIBUTE_DEFINITION
-            ),
+            {
+                PROP_RESOURCE: (
+                    RN_NUMERIC_ATTRIBUTE_DEFINITION
+                    if "Numeric" in attribute["type"]
+                    else RN_STRING_ATTRIBUTE_DEFINITION
+                )
+            },
         )
         for attribute in select(
             CLIENT,
@@ -904,13 +914,20 @@ def list_users():
         print_numbered_object_list(CLIENT, users, object_type_name="User")
         return
 
-    for selected_user in select(CLIENT, users, object_type_name="User"):
-        add_groups_field = {
-            "groups": [
-                group.name for group in get_user_groups(CLIENT, selected_user.id)
-            ]
-        }
-        print_yd_object(selected_user, add_fields=add_groups_field)
+    # Add the list of groups to the user details
+    print_yd_object_list(
+        [
+            (
+                user,
+                {
+                    PROP_GROUPS: [
+                        group.name for group in get_user_groups(CLIENT, user.id)
+                    ]
+                },
+            )
+            for user in select(CLIENT, users)
+        ]
+    )
 
 
 def list_applications():
@@ -929,13 +946,22 @@ def list_applications():
         print_numbered_object_list(CLIENT, applications, object_type_name="Application")
         return
 
-    for selected_app in select(CLIENT, applications, object_type_name="Application"):
-        add_groups_field = {
-            "groups": [
-                group.name for group in get_application_groups(CLIENT, selected_app.id)
-            ]
-        }
-        print_yd_object(selected_app, add_fields=add_groups_field)
+    # Add the list of group names for each application
+    print_yd_object_list(
+        [
+            (
+                application,
+                {
+                    PROP_GROUPS: [
+                        group.name
+                        for group in get_application_groups(CLIENT, application.id)
+                    ],
+                    PROP_RESOURCE: RN_APPLICATION,
+                },
+            )
+            for application in select(CLIENT, applications)
+        ]
+    )
 
 
 def list_groups():
@@ -951,15 +977,24 @@ def list_groups():
     group_summaries.sort(key=lambda group: group.name if group.name is not None else "")
 
     groups: List[Group] = [
-        CLIENT.account_client.get_group(x.id) for x in group_summaries
+        CLIENT.account_client.get_group(group.id) for group in group_summaries
     ]
 
     if not ARGS_PARSER.details:
         print_numbered_object_list(CLIENT, groups, object_type_name="Group")
         return
 
-    for selected_users in select(CLIENT, groups, object_type_name="Group"):
-        print_yd_object(selected_users)
+    selected_groups = select(CLIENT, groups)
+
+    # If stripping IDs, just supply the list of role names;
+    # subverts the type
+    if ARGS_PARSER.strip_ids:
+        for group in selected_groups:
+            group.roles = [group_role.role.name for group_role in group.roles]
+
+    print_yd_object_list(
+        [(group, {PROP_RESOURCE: RN_GROUP}) for group in selected_groups]
+    )
 
 
 def list_roles():
@@ -986,8 +1021,9 @@ def list_roles():
         print_numbered_object_list(CLIENT, roles, object_type_name="Role")
         return
 
-    for selected_users in select(CLIENT, roles, object_type_name="Role"):
-        print_yd_object(selected_users)
+    print_yd_object_list(
+        [(role, {PROP_RESOURCE: RN_ROLE}) for role in select(CLIENT, roles)]
+    )
 
 
 def list_permissions():
