@@ -19,6 +19,8 @@ from yellowdog_client.model import (
 )
 
 from yellowdog_cli.utils.entity_utils import (
+    clear_application_caches,
+    clear_group_caches,
     find_compute_requirement_template_id_by_name,
     find_compute_source_template_id_by_name,
     get_application_id_by_name,
@@ -496,6 +498,9 @@ def remove_namespace_policy(resource: Dict):
         print_error(f"Namespace Policy '{namespace}' not found")
         return
 
+    if not confirmed(f"Remove Namespace Policy '{namespace}'?"):
+        return
+
     try:
         CLIENT.namespaces_client.delete_namespace_policy(namespace)
         print_log(f"Removed Namespace Policy '{namespace}'")
@@ -518,9 +523,13 @@ def remove_group(resource: Dict):
         print_warning(f"Group '{group_name}' not found")
         return
 
+    if not confirmed(f"Remove Group '{group_name}' ({group_id})?"):
+        return
+
     try:
         CLIENT.account_client.delete_group(group_id)
         print_log(f"Removed Group '{group_name}' ({group_id})")
+        clear_group_caches()
     except Exception as e:
         print_error(f"Unable to delete Group '{group_name}' ({group_id}): {e}")
 
@@ -540,11 +549,15 @@ def remove_application(resource: Dict):
         print_warning(f"Application '{app_name}' not found")
         return
 
+    if not confirmed(f"Remove Application '{app_name}' ({app_id})?"):
+        return
+
     try:
         CLIENT.account_client.delete_application(app_id)
         print_log(f"Removed Application '{app_name}' ({app_id})")
+        clear_application_caches()
     except Exception as e:
-        print_error(f"Unable to delete Application '{app_name}' ({app_id}): {e}")
+        print_error(f"Unable to remove Application '{app_name}' ({app_id}): {e}")
 
 
 # Entry point
