@@ -7,7 +7,10 @@ import sys
 from typing import List, Optional
 
 from yellowdog_cli.__init__ import __version__
-from yellowdog_cli.utils.settings import MAX_PARALLEL_TASK_BATCH_UPLOAD_THREADS
+from yellowdog_cli.utils.settings import (
+    DEFAULT_URL,
+    MAX_PARALLEL_TASK_BATCH_UPLOAD_THREADS,
+)
 from yellowdog_cli.version import DOCS_URL
 
 
@@ -66,24 +69,23 @@ class CLIParser:
             "-k",
             type=str,
             required=False,
-            help="the YellowDog Application key",
-            metavar="<app-key>",
+            help="the application key ID",
+            metavar="<app-key-id>",
         )
         parser.add_argument(
             "--secret",
             "-s",
             required=False,
             type=str,
-            help="the YellowDog Application secret",
-            metavar="<app-secret>",
+            help="the application key secret",
+            metavar="<app-key-secret>",
         )
-
         parser.add_argument(
             "--url",
             "-u",
             type=str,
             required=False,
-            help="the URL of the YellowDog Platform API",
+            help=f"the YellowDog Platform API URL (defaults to '{DEFAULT_URL}')",
             metavar="<url>",
         )
         parser.add_argument(
@@ -105,7 +107,6 @@ class CLIParser:
             required=False,
             help="disable colouring and text wrapping in command output",
         )
-
         parser.add_argument(
             "--quiet",
             "-q",
@@ -113,6 +114,12 @@ class CLIParser:
             required=False,
             help="suppress (non-error, non-interactive) status and progress messages",
         )
+        parser.add_argument(
+            "--env-override",
+            action="store_true",
+            required=False,
+            help="values in '.env' file override values in the environment",
+        )
 
         # Module-specific argument sets
         if not any(module in sys.argv[0] for module in ["compare"]):
@@ -401,6 +408,7 @@ class CLIParser:
                 "boost",
                 "hold",
                 "start",
+                "list",
             ]
         ):
             parser.add_argument(
@@ -408,7 +416,10 @@ class CLIParser:
                 "-y",
                 action="store_true",
                 required=False,
-                help="perform modifying actions without requiring user confirmation",
+                help=(
+                    "perform modifying/destructive actions without "
+                    "requiring user confirmation"
+                ),
             )
 
         if any(module in sys.argv[0] for module in ["delete", "download"]):
@@ -657,21 +668,11 @@ class CLIParser:
                 required=False,
                 help="show the full JSON representation of objects",
             )
-            parser.add_argument(
-                "--output-file",
-                type=str,
-                required=False,
-                help=(
-                    "if specified, the 'details' JSON resource listing will also be written "
-                    "to the nominated output file"
-                ),
-                metavar="<output-file>",
-            )
             parser.add_argument(
                 "--auto-select-all",
                 action="store_true",
                 required=False,
-                help="use with '--details' to select all objects automatically",
+                help="automatically select all listed objects (implies '--details')",
             )
 
         if any(module in sys.argv[0] for module in ["upload"]):
@@ -1171,8 +1172,10 @@ class CLIParser:
                 action="store_true",
                 required=False,
                 help=(
-                    "use with '--details' to substitute compute source template IDs and "
-                    "image family IDs for names in detailed compute requirement templates"
+                    "substitute compute source template IDs and image family IDs "
+                    "for names in detailed compute requirement templates, "
+                    "and image family IDs in compute source templates "
+                    "(implies '--details')"
                 ),
             )
             parser.add_argument(
@@ -1180,10 +1183,22 @@ class CLIParser:
                 action="store_true",
                 required=False,
                 help=(
-                    "use with '--details' to omit the YellowDog IDs of objects from "
-                    "their JSON representations"
+                    "omit the YellowDog IDs of objects from their JSON "
+                    "representations, as well as other properties not "
+                    "required when capturing JSON for use with yd-create and yd-remove "
+                    "(implies '--details')"
                 ),
             )
+            parser.add_argument(
+                "--output-file",
+                type=str,
+                required=False,
+                help=(
+                    "if specified, the detailed JSON resource listing will also be written "
+                    "to the nominated output file"
+                ),
+                metavar="<output-file>",
+            )
 
         if "compare" in sys.argv[0]:
             parser.add_argument(
@@ -1255,6 +1270,11 @@ class CLIParser:
     def quiet(self) -> Optional[bool]:
         return self.args.quiet
 
+    @property
+    @allow_missing_attribute
+    def env_override(self) -> Optional[bool]:
+        return self.args.env_override
+
     @property
     @allow_missing_attribute
     def work_req_file(self) -> Optional[str]:
